# Generated by Django 4.2.13 on 2024-08-13 14:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0219_alter_enterprisecatalogquery_content_filter'),
    ]

    operations = [
        migrations.AlterField(
            model_name='updateroleassignmentswithcustomersconfig',
            name='role',
            field=models.CharField(blank=True, choices=[('enterprise_admin', 'enterprise_admin'), ('enterprise_learner', 'enterprise_learner'), ('enterprise_catalog_admin', 'enterprise_catalog_admin'), ('enterprise_provisioning_admin', 'enterprise_provisioning_admin'), ('enterprise_openedx_operator', 'enterprise_openedx_operator')], help_text='Specifies which user role assignments to update.  If unspecified, will update for all roles.', max_length=100),
        ),
    ]
