# Generated by Django 3.2.12 on 2022-07-18 21:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0014_genericenterprisecustomerpluginconfiguration_dry_run_mode_enabled'),
    ]

    operations = [
        migrations.RenameField(
            model_name='contentmetadataitemtransmission',
            old_name='deleted_at',
            new_name='remote_deleted_at'
        ),
        migrations.AlterField(
            model_name='contentmetadataitemtransmission',
            name='remote_deleted_at',
            field=models.DateTimeField(blank=True, help_text='Date when the content transmission was deleted in the remote API', null=True),
        ),
        migrations.AddField(
            model_name='contentmetadataitemtransmission',
            name='api_response_body',
            field=models.TextField(blank=True, help_text='The most recent remote API call response body', null=True),
        ),
        migrations.AddField(
            model_name='contentmetadataitemtransmission',
            name='api_response_status_code',
            field=models.PositiveIntegerField(blank=True, help_text='The most recent remote API call response HTTP status code', null=True),
        ),
        migrations.AddField(
            model_name='contentmetadataitemtransmission',
            name='remote_created_at',
            field=models.DateTimeField(blank=True, help_text='Date when the content transmission was created in the remote API', null=True),
        ),
        migrations.AddField(
            model_name='contentmetadataitemtransmission',
            name='remote_updated_at',
            field=models.DateTimeField(blank=True, help_text='Date when the content transmission was last updated in the remote API', null=True),
        ),
    ]
