# Generated by Django 3.2.20 on 2023-09-26 16:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0186_auto_20230921_1828'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerssoconfiguration',
            name='display_name',
            field=models.CharField(blank=True, help_text='The display name of the SSO configuration.', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomerssoconfiguration',
            name='display_name',
            field=models.CharField(blank=True, help_text='The display name of the SSO configuration.', max_length=255, null=True),
        ),
    ]
