# Generated by Django 3.2.23 on 2024-03-05 09:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0033_integratedchannelapirequestlogs_channel_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='contentmetadataitemtransmission',
            name='remote_errored_at',
            field=models.DateTimeField(blank=True, help_text='Date when the content transmission was failed in the remote API.', null=True),
        ),
    ]
