# Generated by Django 2.2.17 on 2021-02-10 09:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0122_remove_field_sync_enterprise_catalog_query'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomeridentityprovider',
            name='default_provider',
            field=models.BooleanField(default=False, help_text='Specifies whether this is default provider for enterprise customer.'),
        ),
    ]
