# Generated by Django 4.2.15 on 2024-08-08 17:29

import collections
from django.db import migrations
import enterprise.validators
import jsonfield.encoder
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0218_add_provisioning_admin_role'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecatalogquery',
            name='content_filter',
            field=jsonfield.fields.JSONField(blank=True, default={}, dump_kwargs={'cls': jsonfield.encoder.JSONEncoder, 'indent': 4, 'separators': (',', ':')}, help_text="Query parameters which will be used to filter the discovery service's search/all endpoint results, specified as a JSON object. An empty JSON object means that all available content items will be included in the catalog.  Must be unique.", load_kwargs={'object_pairs_hook': collections.OrderedDict}, null=True, validators=[enterprise.validators.validate_content_filter_fields]),
        ),
    ]
