# Generated by Django 3.2.11 on 2022-01-26 18:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moodle', '0008_alter_moodleenterprisecustomerconfiguration_enterprise_customer'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='catalogs_to_transmit',
            field=models.TextField(blank=True, default='', help_text='A comma-separated list of catalog UUIDs to transmit. If blank, all customer catalogs will be transmitted. If there are overlapping courses in the customer catalogs, the overlapping course metadata will be selected from the newest catalog.'),
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='channel_worker_username',
            field=models.CharField(blank=True, default='', help_text='Enterprise channel worker username to get JWT tokens for authenticating LMS APIs.', max_length=255),
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='idp_id',
            field=models.CharField(blank=True, default='', help_text='If provided, will be used as IDP slug to locate remote id for learners', max_length=255),
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='moodle_base_url',
            field=models.CharField(blank=True, help_text='The base URL used for API requests to Moodle', max_length=255, verbose_name='Moodle Base URL'),
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='password',
            field=models.CharField(blank=True, default='', help_text="The API user's password used to obtain new tokens.", max_length=255, verbose_name='Webservice Password'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='service_short_name',
            field=models.CharField(blank=True, help_text='The short name for the Moodle webservice.', max_length=255, verbose_name='Webservice Short Name'),
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='token',
            field=models.CharField(blank=True, default='', help_text="The user's token for the Moodle webservice.", max_length=255, verbose_name='Webservice User Token'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='historicalmoodleenterprisecustomerconfiguration',
            name='username',
            field=models.CharField(blank=True, default='', help_text="The API user's username used to obtain new tokens.", max_length=255, verbose_name='Webservice Username'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='catalogs_to_transmit',
            field=models.TextField(blank=True, default='', help_text='A comma-separated list of catalog UUIDs to transmit. If blank, all customer catalogs will be transmitted. If there are overlapping courses in the customer catalogs, the overlapping course metadata will be selected from the newest catalog.'),
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='channel_worker_username',
            field=models.CharField(blank=True, default='', help_text='Enterprise channel worker username to get JWT tokens for authenticating LMS APIs.', max_length=255),
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='idp_id',
            field=models.CharField(blank=True, default='', help_text='If provided, will be used as IDP slug to locate remote id for learners', max_length=255),
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='moodle_base_url',
            field=models.CharField(blank=True, help_text='The base URL used for API requests to Moodle', max_length=255, verbose_name='Moodle Base URL'),
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='password',
            field=models.CharField(blank=True, default='', help_text="The API user's password used to obtain new tokens.", max_length=255, verbose_name='Webservice Password'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='service_short_name',
            field=models.CharField(blank=True, help_text='The short name for the Moodle webservice.', max_length=255, verbose_name='Webservice Short Name'),
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='token',
            field=models.CharField(blank=True, default='', help_text="The user's token for the Moodle webservice.", max_length=255, verbose_name='Webservice User Token'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='moodleenterprisecustomerconfiguration',
            name='username',
            field=models.CharField(blank=True, default='', help_text="The API user's username used to obtain new tokens.", max_length=255, verbose_name='Webservice Username'),
            preserve_default=False,
        ),
    ]
