# Generated by Django 3.2.23 on 2024-08-26 09:54

from django.db import migrations
from integrated_channels.sap_success_factors.utils import populate_decrypted_fields_sap_success_factors


class Migration(migrations.Migration):

    dependencies = [
        ('sap_success_factors', '0021_sapsuccessfactorsenterprisecustomerconfiguration_decrypted_secret'),
    ]

    operations = [
        migrations.RunPython(populate_decrypted_fields_sap_success_factors, reverse_code=migrations.RunPython.noop),
    ]
